@@ -20,12 +20,12 @@
 #define EXAMPLEEXPORTER_H
 
 #include <QObject>
-#include <com/ubuntu/content/hub.h>
-#include <com/ubuntu/content/transfer.h>
-#include <com/ubuntu/content/import_export_handler.h>
+#include <com/lomiri/content/hub.h>
+#include <com/lomiri/content/transfer.h>
+#include <com/lomiri/content/import_export_handler.h>
 #include <QDebug>
 
-namespace cuc = com::ubuntu::content;
+namespace cuc = com::lomiri::content;
 
 class ExampleExporter : public cuc::ImportExportHandler
 {
