@@ -34,6 +34,8 @@
 #include <QDebug>
 #include <QIcon>
 
+#include <mutex>
+
 /*!
  * \brief qml_content_hub function to unstatinate the ContentHub as a singleton in QML
  */
@@ -52,10 +54,15 @@ void ContentHubPlugin::initializeEngine(QQmlEngine * engine, const char * uri)
 {
     Q_UNUSED(uri)
     TRACE() << Q_FUNC_INFO;
-    QIcon::setThemeName("suru");
-    QIcon::setThemeSearchPaths(QStringList() << ("/usr/share/icons/"));
-    ContentIconProvider *iconProvider = ContentIconProvider::instance();
-    engine->addImageProvider("content-hub", iconProvider);
+
+    static std::once_flag initOnceFlag;
+
+    std::call_once(initOnceFlag, [&engine]() {
+        QIcon::setThemeName("suru");
+        QIcon::setThemeSearchPaths(QStringList() << ("/usr/share/icons/"));
+        ContentIconProvider *iconProvider = ContentIconProvider::instance();
+        engine->addImageProvider("content-hub", iconProvider);
+    });
 }
 
 /*!
@@ -64,7 +71,11 @@ void ContentHubPlugin::initializeEngine(QQmlEngine * engine, const char * uri)
 void ContentHubPlugin::registerTypes(const char *uri)
 {
     TRACE() << Q_FUNC_INFO;
+#ifdef ENABLE_UBUNTU_COMPAT
+    Q_ASSERT(uri == QLatin1String("Lomiri.Content") || uri == QLatin1String("Ubuntu.Content"));
+#else
     Q_ASSERT(uri == QLatin1String("Lomiri.Content"));
+#endif
 
     QVector<QPair<int, int>> versions;
     versions.append(QPair<int, int>(0, 1));
