@@ -35,23 +35,18 @@ public:
     ContentStore(QObject *parent = nullptr);
 
     const QString &uri() const;
-
-    const com::lomiri::content::Store *store() const;
-    void setStore(const com::lomiri::content::Store *store);
+    void setUri(const QString & uri);
 
     ContentScope::Scope scope();
     void setScope(ContentScope::Scope scope);
 
-    void updateStore(ContentType::Type type);
-
 Q_SIGNALS:
     void uriChanged();
     void scopeChanged();
 
 private:
-    com::lomiri::content::Hub *m_hub;
-    const com::lomiri::content::Store *m_store;
     ContentScope::Scope m_scope;
+    QString m_uri;
 };
 
 #endif // COM_LOMIRI_CONTENTSTORE_H_
