@@ -189,10 +189,17 @@ QDBusObjectPath cucd::Service::CreateImportFromPeer(const QString& peer_id, cons
 {
     TRACE() << Q_FUNC_INFO;
     QString dest_id = app_id;
+    QString aa_profile_id = aa_profile(this->message().service(), "unconfined");
     if (dest_id.isEmpty())
     {
         TRACE() << Q_FUNC_INFO << "APP_ID isnt' set, attempting to get it from AppArmor";
-        dest_id = aa_profile(this->message().service(), "unconfined");
+        dest_id = aa_profile_id;
+    } else if (aa_profile_id != "unconfined" && dest_id != aa_profile_id) {
+        TRACE() << Q_FUNC_INFO << "App with profile '" << aa_profile_id <<
+                                  "' said their ID is '" << dest_id << "'";
+        sendErrorReply(QDBusError::AccessDenied,
+            QStringLiteral("Supplied app ID doesn't match AppArmor profile."));
+        return QDBusObjectPath();
     }
     return CreateTransfer(dest_id, peer_id, cuc::Transfer::Import, type_id);
 }
@@ -294,10 +301,17 @@ QDBusObjectPath cucd::Service::CreateExportToPeer(const QString& peer_id, const
 {
     TRACE() << Q_FUNC_INFO;
     QString src_id = app_id;
+    QString aa_profile_id = aa_profile(this->message().service(), "unconfined");
     if (src_id.isEmpty())
     {
         TRACE() << Q_FUNC_INFO << "APP_ID isnt' set, attempting to get it from AppArmor";
-        src_id = aa_profile(this->message().service(), "unconfined");
+        src_id = aa_profile_id;
+    } else if (aa_profile_id != "unconfined" && src_id != aa_profile_id) {
+        TRACE() << Q_FUNC_INFO << "App with profile '" << aa_profile_id <<
+                                  "' said their ID is '" << src_id << "'";
+        sendErrorReply(QDBusError::AccessDenied,
+            QStringLiteral("Supplied app ID doesn't match AppArmor profile."));
+        return QDBusObjectPath();
     }
     return CreateTransfer(peer_id, src_id, cuc::Transfer::Export, type_id);
 }
@@ -306,10 +320,17 @@ QDBusObjectPath cucd::Service::CreateShareToPeer(const QString& peer_id, const Q
 {
     TRACE() << Q_FUNC_INFO;
     QString src_id = app_id;
+    QString aa_profile_id = aa_profile(this->message().service(), "unconfined");
     if (src_id.isEmpty())
     {
         TRACE() << Q_FUNC_INFO << "APP_ID isnt' set, attempting to get it from AppArmor";
-        src_id = aa_profile(this->message().service(), "unconfined");
+        src_id = aa_profile_id;
+    } else if (aa_profile_id != "unconfined" && src_id != aa_profile_id) {
+        TRACE() << Q_FUNC_INFO << "App with profile '" << aa_profile_id <<
+                                  "' said their ID is '" << src_id << "'";
+        sendErrorReply(QDBusError::AccessDenied,
+            QStringLiteral("Supplied app ID doesn't match AppArmor profile."));
+        return QDBusObjectPath();
     }
     return CreateTransfer(peer_id, src_id, cuc::Transfer::Share, type_id);
 }
@@ -482,12 +503,17 @@ void cucd::Service::handle_imports(int state)
         gchar ** uris = NULL;
         if (d->registry->peer_is_legacy(transfer->destination())) {
             TRACE() << Q_FUNC_INFO << "Destination is a legacy app, collecting";
-            transfer->SetStore(shared_dir_for_peer(transfer->destination()));
+
+            auto store_path = shared_dir_for_peer(transfer->destination());
+            transfer->setStoreInternal(Scope::app, Type::unknown().id(),
+                                       store_path);
             auto items = transfer->Collect();
             gchar* urls[2] = {0};
             gint i = 0;
             Q_FOREACH (QVariant item, items) {
-                QString s = copy_to_store(item.value<cuc::Item>().url().toString(), transfer->Store()).split("/shared")[1];
+                QString s = copy_to_store(
+                    item.value<cuc::Item>().url().toString(),
+                    store_path, /* is_persistent */ true).split("/shared")[1];
                 QUrl u = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + "/shared" + s);
                 urls[i] = g_str_to_ascii(u.toString().toStdString().c_str(), NULL);
                 i++;
@@ -571,13 +597,17 @@ void cucd::Service::handle_exports(int state)
         gchar ** uris = NULL;
         if (d->registry->peer_is_legacy(transfer->destination())) {
             TRACE() << Q_FUNC_INFO << "Destination is a legacy app, collecting";
-            transfer->SetStore(shared_dir_for_peer(transfer->destination()));
+            auto store_path = shared_dir_for_peer(transfer->destination());
+            transfer->setStoreInternal(Scope::app, Type::unknown().id(),
+                                       store_path);
 
             auto items = transfer->Collect();
             gchar* urls[2] = {0};
             gint i = 0;
             Q_FOREACH (QVariant item, items) {
-                QString s = copy_to_store(item.value<cuc::Item>().url().toString(), transfer->Store()).split("/shared")[1];
+                QString s = copy_to_store(
+                    item.value<cuc::Item>().url().toString(),
+                    store_path, /* is_persistent */ true).split("/shared")[1];
                 QUrl u = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + "/shared" + s);
                 urls[i] = g_str_to_ascii(u.toString().toStdString().c_str(), NULL);
                 i++;
