@@ -180,19 +180,24 @@ void cuc::Hub::register_import_export_handler(cuc::ImportExportHandler* handler)
 
 const cuc::Store* cuc::Hub::store_for_scope_and_type(cuc::Scope scope, cuc::Type type)
 {
+#define ENTRY(scope, type, path) \
+    {{scope, type}, new cuc::Store{scope, type, path, this}}
+
     static const std::map<std::pair<cuc::Scope, cuc::Type>, cuc::Store*> lut =
             {
-                {{cuc::system, cuc::Type::Known::pictures()}, new cuc::Store{"/content/Pictures", this}},
-                {{cuc::system, cuc::Type::Known::music()}, new cuc::Store{"/content/Music", this}},
-                {{cuc::system, cuc::Type::Known::documents()}, new cuc::Store{"/content/Documents", this}},
-                {{cuc::user, cuc::Type::Known::pictures()}, new cuc::Store{QStandardPaths::writableLocation(QStandardPaths::PicturesLocation), this}},
-                {{cuc::user, cuc::Type::Known::music()}, new cuc::Store{QStandardPaths::writableLocation(QStandardPaths::MusicLocation), this}},
-                {{cuc::user, cuc::Type::Known::documents()}, new cuc::Store{QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation), this}},
-                {{cuc::app, cuc::Type::Known::pictures()}, new cuc::Store{QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + "/Pictures", this}},
-                {{cuc::app, cuc::Type::Known::music()}, new cuc::Store{QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + "/Music", this}},
-                {{cuc::app, cuc::Type::Known::documents()}, new cuc::Store{QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + "/Documents", this}},
+                ENTRY(cuc::system, cuc::Type::Known::pictures(), QStringLiteral("/content/Pictures")),
+                ENTRY(cuc::system, cuc::Type::Known::music(), QStringLiteral("/content/Music")),
+                ENTRY(cuc::system, cuc::Type::Known::documents(), QStringLiteral("/content/Documents")),
+                ENTRY(cuc::user, cuc::Type::Known::pictures(), QStandardPaths::writableLocation(QStandardPaths::PicturesLocation)),
+                ENTRY(cuc::user, cuc::Type::Known::music(), QStandardPaths::writableLocation(QStandardPaths::MusicLocation)),
+                ENTRY(cuc::user, cuc::Type::Known::documents(), QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation)),
+                ENTRY(cuc::app, cuc::Type::Known::pictures(), QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + "/Pictures"),
+                ENTRY(cuc::app, cuc::Type::Known::music(), QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + "/Music"),
+                ENTRY(cuc::app, cuc::Type::Known::documents(), QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + "/Documents"),
             };
 
+#undef ENTRY
+
     auto it = lut.find(std::make_pair(scope, type));
 
     if (it == lut.end())
@@ -307,8 +312,6 @@ cuc::Transfer* cuc::Hub::create_import_from_peer_for_type(cuc::Peer peer, cuc::T
     }
 
     cuc::Transfer *transfer = cuc::Transfer::Private::make_transfer(reply.value(), this);
-    const cuc::Store *store = new cuc::Store{QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + "/HubIncoming/" + QString::number(transfer->id()), this};
-    transfer->setStore(store);
     return transfer;
 }
 
@@ -334,9 +337,6 @@ cuc::Transfer* cuc::Hub::create_export_to_peer_for_type(cuc::Peer peer, cuc::Typ
 
     QString peerName = peer.id().split("_")[0];
     TRACE() << Q_FUNC_INFO << "peerName: " << peerName;
-    const cuc::Store *store = new cuc::Store{QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + "/" + peerName + "/HubIncoming/" + QString::number(transfer->id()), this};
-    TRACE() << Q_FUNC_INFO << "STORE:" << store->uri();
-    transfer->setStore(store);
     transfer->start();
     return transfer;
 }
@@ -362,9 +362,6 @@ cuc::Transfer* cuc::Hub::create_share_to_peer_for_type(cuc::Peer peer, cuc::Type
     cuc::Transfer *transfer = cuc::Transfer::Private::make_transfer(reply.value(), this);
     QString peerName = peer.id().split("_")[0];
     TRACE() << Q_FUNC_INFO << "peerName: " << peerName;
-    const cuc::Store *store = new cuc::Store{QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + "/" + peerName + "/HubIncoming/" + QString::number(transfer->id()), this};
-    TRACE() << Q_FUNC_INFO << "STORE:" << store->uri();
-    transfer->setStore(store);
     transfer->start();
     return transfer;
 }
