@@ -276,14 +276,7 @@ QString aa_profile(QString uniqueConnectionId, QString returnValueOnError = QStr
     return aaProfile;
 }
 
-bool is_persistent(QString store)
-{
-    TRACE() << Q_FUNC_INFO << store;
-    QRegularExpression rx = QRegularExpression(".*\\.cache/.*/HubIncoming/.*");
-    return not rx.match(store).hasMatch();
-}
-
-QString copy_to_store(const QString& src, const QString& store)
+QString copy_to_store(const QString& src, const QString& store, bool is_persistent)
 {
     TRACE() << Q_FUNC_INFO;
     QUrl srcUrl(src);
@@ -311,7 +304,7 @@ QString copy_to_store(const QString& src, const QString& store)
     }
     TRACE() << Q_FUNC_INFO << destFilePath;
     bool copy_failed = true;
-    if (not is_persistent(store))
+    if (not is_persistent)
     {
         if (link( fi.absoluteFilePath().toStdString().c_str(),
             destFilePath.toStdString().c_str() ) < 0)
@@ -333,12 +326,6 @@ bool purge_store_cache(QString store)
 {
     TRACE() << Q_FUNC_INFO << "Store:" << store;
 
-    if (is_persistent(store))
-    {
-        TRACE() << Q_FUNC_INFO << store << "is persistent";
-        return false;
-    }
-
     QDir st(store);
     if (st.exists())
     {
