@@ -33,7 +33,19 @@ bool is_child(pid_t pid)
     return pid == 0;
 }
 
-int fork_and_run(std::function<void()> child, std::function<void()> parent)
+int wait_for_child(int pid)
+{
+    int status;
+    if (0 > waitpid( pid, &status, 0))
+        return -1;
+
+    if (WIFEXITED(status))
+        return WEXITSTATUS(status);
+    else
+        return -2;
+}
+
+int fork_and_run(std::function<bool()> child, std::function<void()> parent)
 {
     auto pid = fork();
 
@@ -44,14 +56,16 @@ int fork_and_run(std::function<void()> child, std::function<void()> parent)
 
     if (is_child(pid))
     {
-        child();
-        return EXIT_SUCCESS;
+        int err = child();
+        _exit(err);
+        return err ? EXIT_FAILURE : EXIT_SUCCESS;
     }
     else
     {
         parent();
+        int err = wait_for_child(pid);
         kill(pid, SIGKILL);
-        return EXIT_SUCCESS;
+        return err ? EXIT_FAILURE : EXIT_SUCCESS;
     }
 
     return EXIT_FAILURE;
