@@ -21,7 +21,7 @@
 
 #include "autoimporter.h"
 
-namespace cuc = com::ubuntu::content;
+namespace cuc = com::lomiri::content;
 
 int main(int argc, char *argv[])
 {
